@@ -34,10 +34,10 @@ test_fixtures$github_repository_rest_response <- list(
   "id" = 627452680,
   "node_id" = "R_kgDOJWYrCA",
   "name" = "testRepo",
-  "full_name" = "test-org/TestRepo",
+  "full_name" = "test_org/TestRepo",
   "private" = FALSE,
   "owner" = list(
-    "login" = "test-org",
+    "login" = "test_org",
     "id" = 103638913,
     "node_id" = "O_kgDOBi1ngQ",
     "avatar_url" = "https://avatars.githubusercontent.com/u/103638913?v=4"
@@ -96,40 +96,42 @@ test_fixtures$gitlab_repositories_rest_response <- list(
   )
 )
 
-github_repository_node <- list(
-  "repo_id" = "xyz",
-  "repo_name" = "TestRepo",
-  "default_branch" = list(
-    "name" = "main"
-  ),
-  "stars" = 10,
-  "forks" = 2,
-  "created_at" = "2022-04-20T00:00:00Z",
-  "last_activity_at" = "2023-04-20T00:00:00Z",
-  "languages" = list(
-    "nodes" = list(
-      list(
-        "name" = "R"
-      ),
-      list(
-        "name" = "CSS"
-      ),
-      list(
-        "name" = "JavaScript"
+github_repository_node <- function(repo_name) {
+  list(
+    "repo_id" = "xyz",
+    "repo_name" = repo_name,
+    "default_branch" = list(
+      "name" = "main"
+    ),
+    "stars" = 10,
+    "forks" = 2,
+    "created_at" = "2022-04-20T00:00:00Z",
+    "last_activity_at" = "2023-04-20T00:00:00Z",
+    "languages" = list(
+      "nodes" = list(
+        list(
+          "name" = "R"
+        ),
+        list(
+          "name" = "CSS"
+        ),
+        list(
+          "name" = "JavaScript"
+        )
       )
-    )
-  ),
-  "issues_open" = list(
-    "totalCount" = 10
-  ),
-  "issues_closed" = list(
-    "totalCount" = 5
-  ),
-  "organization" = list(
-    "login" = "test_org"
-  ),
-  "repo_url" = "https://test_url"
-)
+    ),
+    "issues_open" = list(
+      "totalCount" = 10
+    ),
+    "issues_closed" = list(
+      "totalCount" = 5
+    ),
+    "organization" = list(
+      "login" = "test_org"
+    ),
+    "repo_url" = "https://test_url"
+  )
+}
 
 test_fixtures$github_repos_by_org_response <- list(
   "data" = list(
@@ -141,11 +143,11 @@ test_fixtures$github_repos_by_org_response <- list(
           "hasNextPage" = FALSE
         ),
         "nodes" = list(
-          github_repository_node,
-          github_repository_node,
-          github_repository_node,
-          github_repository_node,
-          github_repository_node
+          github_repository_node("TestRepo"),
+          github_repository_node("TestRepo1"),
+          github_repository_node("TestRepo2"),
+          github_repository_node("TestRepo3"),
+          github_repository_node("TestRepo4")
         )
       )
     )
@@ -162,11 +164,11 @@ test_fixtures$github_repos_by_user_response <- list(
           "hasNextPage" = FALSE
         ),
         "nodes" = list(
-          github_repository_node,
-          github_repository_node,
-          github_repository_node,
-          github_repository_node,
-          github_repository_node
+          github_repository_node("TestRepo"),
+          github_repository_node("TestRepo1"),
+          github_repository_node("TestRepo2"),
+          github_repository_node("TestRepo3"),
+          github_repository_node("TestRepo4")
         )
       )
     )
@@ -245,24 +247,30 @@ test_fixtures$gitlab_repos_by_user_response <- list(
   )
 )
 
-github_commit_edge <- list(
-  "node" = list(
-    "id" = "xxx",
-    "committed_date" = "2023-01-25T10:26:41Z",
-    "author" = list(
-      "name" = "Maciej Banas",
-      "user" = list(
-        "name" = "Maciej Banas",
-        "login" = "maciekbanas"
+github_commit_edge <- function(timestamp, author) {
+  list(
+    "node" = list(
+      "id" = "xxx",
+      "committed_date" = timestamp,
+      "author" = list(
+        "name" = author,
+        "user" = list(
+          "name" = "Maciej Banas",
+          "login" = "maciekbanas"
+        )
+      ),
+      "additions" = 5L,
+      "deletions" = 8L,
+      "repository" = list(
+        "url" = "test_url"
       )
-    ),
-    "additions" = 5L,
-    "deletions" = 8L,
-    "repository" = list(
-      "url" = "test_url"
     )
   )
-)
+}
+
+set.seed(123)
+commit_timestamps <- generate_random_timestamps(25, 2023, 2024)
+commit_authors <- generate_random_names(25, c("John Test", "Barbara Check", "Bob Test"))
 
 test_fixtures$github_commits_response <- list(
   "data" = list(
@@ -270,9 +278,7 @@ test_fixtures$github_commits_response <- list(
       "defaultBranchRef" = list(
         "target" = list(
           "history" = list(
-            "edges" = list(
-              rep(github_commit_edge, 5)
-            )
+            "edges" = purrr::map2(commit_timestamps, commit_authors, github_commit_edge)
           )
         )
       )
@@ -305,9 +311,7 @@ gitlab_commit <- list(
   )
 )
 
-test_fixtures$gitlab_commits_response <- list(
-  rep(gitlab_commit, 5)
-)
+test_fixtures$gitlab_commits_response <- rep(list(gitlab_commit), 5)
 
 test_fixtures$github_file_response <- list(
   "data" = list(
@@ -354,7 +358,7 @@ test_fixtures$gitlab_file_org_response <- list(
                 "blobs" = list(
                   "nodes" = list(
                     list(
-                      "name" = "meta_data.yaml",
+                      "path" = "meta_data.yaml",
                       "rawBlob" = "Some interesting text",
                       "size" = 4
                     )
@@ -372,7 +376,7 @@ test_fixtures$gitlab_file_org_response <- list(
                 "blobs" = list(
                   "nodes" = list(
                     list(
-                      "name" = "meta_data.yaml",
+                      "path" = "meta_data.yaml",
                       "rawBlob" = "Some interesting text",
                       "size" = 5
                     )
@@ -397,12 +401,12 @@ test_fixtures$gitlab_file_repo_response <- list(
         "blobs" = list(
           "nodes" = list(
             list(
-              "name" = "README.md",
+              "path" = "README.md",
               "rawBlob" = "# graphql_tests\n\nThis project is for testing GraphQL capabilities.\n",
               "size" =  "67"
             ),
             list(
-              "name" = "project_metadata.yaml",
+              "path" = "project_metadata.yaml",
               "rawBlob" = "Name: GraphQL Tests",
               "size" = "19"
             )
@@ -413,20 +417,6 @@ test_fixtures$gitlab_file_repo_response <- list(
   )
 )
 
-test_fixtures$github_png_file_response <- list(
-  "data" = list(
-    "repository" = list(
-      "repo_id"   = "01010101",
-      "repo_name" = "TestProject",
-      "repo_url"  = "https://github.com/r-world-devs/GitStats",
-      "file" = list(
-        "text" = NULL,
-        "byteSize" = 50L
-      )
-    )
-  )
-)
-
 test_fixtures$gitlab_search_response <- list(
   list(
     "basename"   = "test",
@@ -523,7 +513,7 @@ test_fixtures$github_files_tree_response <- list(
     "repository" = list(
       "id"     = "R_kgD0Ivtxsg",
       "name"   = "TestRepo",
-      "url"    = "https://github.com/test-org/TestRepo",
+      "url"    = "https://github.com/test_org/TestRepo",
       "object" = list(
         "entries" = list(
           list(
